@@ -1,9 +1,9 @@
 /*
- * $Id: dialog.c,v 1.284 2021/03/06 13:41:57 tom Exp $
+ * $Id: dialog.c,v 1.288 2022/04/06 08:04:56 tom Exp $
  *
  *  cdialog - Display simple dialog boxes from shell scripts
  *
- *  Copyright 2000-2020,2021	Thomas E. Dickey
+ *  Copyright 2000-2021,2022	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -24,16 +24,6 @@
  *	Savio Lam (lam836@cs.cuhk.hk)
  */
 
-#include <dialog.h>
-
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
-#ifdef HAVE_SETLOCALE
-#include <locale.h>
-#endif
-
 #include <dlg_internals.h>
 
 #define USEMAX_ARGS	20
@@ -903,9 +893,6 @@ call_inputmenu(CALLARGS)
 
     dialog_vars.input_menu = TRUE;
 
-    if (dialog_vars.max_input == 0)
-	dialog_vars.max_input = MAX_LEN / 2;
-
     if (dialog_vars.extra_label == 0) {
 	free_extra_label = TRUE;
 	dialog_vars.extra_label = dlg_strclone(_("Rename"));
@@ -1551,7 +1538,7 @@ Help(void)
     static const char *const tbl_1[] =
     {
 	"cdialog (ComeOn Dialog!) version %s",
-	"Copyright 2000-2020,2021 Thomas E. Dickey",
+	"Copyright 2000-2021,2022 Thomas E. Dickey",
 	"This is free software; see the source for copying conditions.  There is NO",
 	"warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.",
 	"",
